lfs_dir

Function lfs_dir 

pub fn lfs_dir(cwd: &Path) -> Result<PathBuf, Error>
Path to the LFS storage directory (<common-git-dir>/lfs). The directory is not created. Routed through git_common_dir so a linked worktree shares the same on-disk LFS object cache as its main repo — git lfs prune from one worktree sees the same 100% of objects as git lfs fetch from another.